<?php


/**
 * Batch callback.
 *
 * @param array $uids
 * @param stdClass $node
 * @param bool $replytoinfoat
 */
function cforge_broadcast_batch_mail(array $uids, stdClass  $node, $replytoinfoat) {
  module_load_include('inc','cforge_broadcast');
  $params = array(
    'node' => $node,
    'replytoinfoat' => $replytoinfoat
  );
  $sender = user_load($node->uid);
  if ($node->type == 'proposition') {
    $type = $node->want ? t('Want') : t('Offer');
  }
  else {
    $type = node_type_get_type($node->type)->name;
  }
  $params['body'][] = t('@name [!contact] posted a new @type.', array(
    '@name' => $sender->name,
    '!contact' => l(t('contact'), url('user/'.$sender->uid.'/contact', array('absolute' =>TRUE))),
    '@type' => $type
  ));

  $render = node_view($node);
  unset($render['comments']);
  $params['body'][] = drupal_render($render);
  if (isset($node->upload) && is_array($node->upload)) {
    $items = (array)reset($node->upload);
    foreach($items as $att) {
      if (!$att['fid']) {
        continue;
      }
      $file = file_load($att['fid']);
      $params['attachments'][] = array(
        'uri' => $file->uri,
        'filecontent' => file_get_contents($file->uri),
        'filename' => $file->filename,
        'filemime' => file_get_mimetype($file->uri)
      );
    }
  }
  $from = variable_get('site_mail');
  foreach(user_load_multiple($uids) as $account) {
    if (variable_get('cforge_broadcast_optout', 0)) {
      if (array_key_exists('cforge_broadcast_optout', $account->data) && $account->data['cforge_broadcast_optout']) {
        continue;
      }
    }
    drupal_mail(
      'cforge_broadcast',
      'broadcast',
      $account->mail,
      user_preferred_language($account),
      $params, // Does NOT contain 'account' - same for all mails
      $from,
      TRUE // Really send
    );
  }
}


/**
 * Implements hook_form_node_form_alter().
 *
 * Add the broadcast form items
 */
function _cforge_broadcast_form_node_form_alter(&$form, &$form_state) {
  if ($GLOBALS['user']->uid != 1) {
    $form['options'][NODE_BROADCAST_FLAG]['#access'] = FALSE;
  }
  else {
    $form['options'][NODE_BROADCAST_FLAG]['#title'] = t('Has been broadcast');
  }

  if (in_array($form['#node']->type, array('proposition', 'story', 'document', 'event' ))) {
    $form['options']['status']['#description'] = t("Uncheck this to hide this item");
    if (!$form['#node']->{NODE_BROADCAST_FLAG}) {
      $broadcast_options = array(
        '' => '--'. t('Choose').'--',
        'user_chooser_segment_me' => t('Just to me'),
        'user_chooser_segment_roles:'.RID_TRADER => t('All other active traders'),
        'user_chooser_segment_neighbourhood' => t('Everyone in my neighbourhood'),
      );
      //check if and to whom the current user can broadcast, then present the appropriate widget
      if (!user_access('administer nodes', $GLOBALS['user'])) {
        switch (variable_get('cforge_broadcast_trader_range', 'none')) {
          case 'none':
            return;
          case 'all':
            break;
          case 'neighbourhood':
            unset($broadcast_options['user_chooser_segment_roles:3']);
        }
      }
      $form['broadcast'] = array(
        '#title' => t('Broadcast'),
        '#description' => t('This can only be broadcast once.'),
        '#type' => 'fieldset',
        '#weight' => 100,
        'audience' => array(
          '#title' => t('Send to'),
          '#type' => 'user_chooser_many',
          '#weight' => 1,
          '#options' => $broadcast_options,
          '#required' => FALSE
        ),
        'replytoinfoat' => array(
          '#title' => t('Reply to: @mail', array('@mail' => variable_get('site_mail'))),
          '#type' => 'checkbox',
          '#access' => user_access('bypass_node_access'),//that means RID_COMMITTEE
          '#weight' => 2,
          '#required' => FALSE
        ),
        'send' => array(
          '#type' => 'submit',
          '#description' => t('Each item can be broadcast only once.'),
          '#weight' => 3,
          '#value' => t('Save & Broadcast'),
          '#submit' => array('node_broadcast_submit'),
          '#attributes' => array('onclick' => 'if(!confirm("'.t('Are you sure you want to broadcast this?').'")){return false;}'),
        ),
      );
      if (count($form['broadcast']['audience']['#options']) == 1) {
        $form['broadcast']['audience']['#value'] = key($form['broadcast']['audience']['#options']);
        $form['broadcast']['send']['#value'] = t(
          'Save & Broadcast to: @whoever',
          array('@whoever' => current($form['broadcast']['audience']['#options']))
        );
      }
      if (isset($form['image'])) {
        $form['broadcast']['#description'] .= ' '.t('Images cannot be included in broadcast mails');
      }
      $form['#validate'][] = 'node_broadcast_validate';
    }
  }
}
